@@ -46,6 +46,7 @@
 check_content <- function(x, valid, name = NULL, general = NULL,
                           specific = NULL, supplement = NULL,
                           as_double = TRUE, ...) {
+  if (is.null(name)) name <- deparse(substitute(x))
   check_length(x, 1, name, general, specific, supplement, ...)
 
   if (is.function(valid)) {
@@ -74,10 +75,6 @@ check_content <- function(x, valid, name = NULL, general = NULL,
     return(invisible(NULL))
   }
 
-  if (is.null(name)) {
-    name <- deparse(substitute(x))
-  }
-
   if (is.null(general)) {
     s_valid <- phrase_valid_content(valid, as_double)
 
